NormalOut2

Trait NormalOut2 

pub trait NormalOut2 {
    // Required methods
    fn __add(self, rhs: Self) -> Self;
    fn __sub(self, rhs: Self) -> Self;
    fn __mul_add(self, a: Self, b: Self) -> Self;
    fn __mul(self, rhs: Self) -> Self;
    fn __rem(self, rhs: Self) -> Self;
    fn __max(self, rhs: Self) -> Self;
    fn __min(self, rhs: Self) -> Self;
    fn __clamp(self, min: Self, max: Self) -> Self;
}
internal trait for normal out

Required Methods

fn __add(self, rhs: Self) -> Self

perform a + b

fn __sub(self, rhs: Self) -> Self

perform a - b

fn __mul_add(self, a: Self, b: Self) -> Self

perform self * a + b, fused multiply add if the hardware supports it, it can speed up the calculation and reduce the rounding error

fn __mul(self, rhs: Self) -> Self

perform a * b

fn __rem(self, rhs: Self) -> Self

perform a % b

fn __max(self, rhs: Self) -> Self

perform max(x, y)

fn __min(self, rhs: Self) -> Self

perform min(x, y)

fn __clamp(self, min: Self, max: Self) -> Self

restrict the value of x to the range [min, max]

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl NormalOut2 for bool

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, _: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, _: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, _: Self, _: Self) -> Self

Source

impl NormalOut2 for f32

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for f64

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for i8

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for i16

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for i32

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for i64

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for i128

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for isize

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for u8

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for u16

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for u32

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for u64

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for u128

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for usize

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for bf16

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for f16

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for Complex<f32>

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Source

impl NormalOut2 for Complex<f64>

Source

fn __add(self, rhs: Self) -> Self

Source

fn __sub(self, rhs: Self) -> Self

Source

fn __mul_add(self, a: Self, b: Self) -> Self

Source

fn __mul(self, rhs: Self) -> Self

Source

fn __rem(self, rhs: Self) -> Self

Source

fn __max(self, rhs: Self) -> Self

Source

fn __min(self, rhs: Self) -> Self

Source

fn __clamp(self, min: Self, max: Self) -> Self

Implementors